Contributing
============

Contributions are welcome, and they are greatly appreciated! Every
little bit helps.

You can contribute in many ways:

Types of Contributions
----------------------

### Report Bugs

Report bugs at <https://github.com/hpyproject/hpy/issues>.

When reporting a bug, please include:

- Your operating system name and version.
- Any details about your local setup that might be helpful in
    troubleshooting.
- Detailed steps to reproduce the bug.

### Donate to HPy

Become a financial contributor and help us sustain the HPy community: [Contribute to HPy](https://opencollective.com/hpy/contribute).

### Fix Bugs or Implement Features

Look through the GitHub issues for bugs or proposals being discussed
or ready for implementation.

### Write Documentation

HPy could always use more documentation, whether as part of the
official HPy docs, in docstrings, or even on the web in blog
posts, articles, and such.

Get Started!
------------

You can test your environment by running 

```bash
proof-of-concept/test_pof.sh wheel universal
```

This should build HPy and a proof of concept (demo) extension and
then run a pytest that validates both.

Until we get around to more comprehensive documentation, you
can reverse engineer how the system works by looking at these
files:

- `proof-of-concept/test_pof.sh`
- `proof-of-concept/setup.py`
